@@ -326,14 +326,16 @@ class FractionTest(unittest.TestCase):
     def testConversions(self):
         self.assertTypedEquals(-1, math.trunc(F(-11, 10)))
         self.assertTypedEquals(1, math.trunc(F(11, 10)))
-        self.assertTypedEquals(-2, math.floor(F(-11, 10)))
-        self.assertTypedEquals(-1, math.ceil(F(-11, 10)))
-        self.assertTypedEquals(-1, math.ceil(F(-10, 10)))
+        if sys.version_info[0] >= 3:
+            self.assertTypedEquals(-2, math.floor(F(-11, 10)))
+            self.assertTypedEquals(-1, math.ceil(F(-11, 10)))
+            self.assertTypedEquals(-1, math.ceil(F(-10, 10)))
         self.assertTypedEquals(-1, int(F(-11, 10)))
-        self.assertTypedEquals(0, round(F(-1, 10)))
-        self.assertTypedEquals(0, round(F(-5, 10)))
-        self.assertTypedEquals(-2, round(F(-15, 10)))
-        self.assertTypedEquals(-1, round(F(-7, 10)))
+        if sys.version_info[0] >= 3:
+            self.assertTypedEquals(0, round(F(-1, 10)))
+            self.assertTypedEquals(0, round(F(-5, 10)))
+            self.assertTypedEquals(-2, round(F(-15, 10)))
+            self.assertTypedEquals(-1, round(F(-7, 10)))
 
         self.assertEqual(False, bool(F(0, 1)))
         self.assertEqual(True, bool(F(3, 2)))
@@ -348,11 +350,12 @@ class FractionTest(unittest.TestCase):
         self.assertTypedEquals(0.1+0j, complex(F(1,10)))
 
     def testRound(self):
-        self.assertTypedEquals(F(-200), round(F(-150), -2))
-        self.assertTypedEquals(F(-200), round(F(-250), -2))
-        self.assertTypedEquals(F(30), round(F(26), -1))
-        self.assertTypedEquals(F(-2, 10), round(F(-15, 100), 1))
-        self.assertTypedEquals(F(-2, 10), round(F(-25, 100), 1))
+        if sys.version_info[0] >= 3:
+            self.assertTypedEquals(F(-200), round(F(-150), -2))
+            self.assertTypedEquals(F(-200), round(F(-250), -2))
+            self.assertTypedEquals(F(30), round(F(26), -1))
+            self.assertTypedEquals(F(-2, 10), round(F(-15, 100), 1))
+            self.assertTypedEquals(F(-2, 10), round(F(-25, 100), 1))
 
     def testArithmetic(self):
         self.assertEqual(F(1, 2), F(1, 10) + F(2, 5))
@@ -404,10 +407,16 @@ class FractionTest(unittest.TestCase):
         self.assertTypedEquals(10.0 + 0j, (1.0 + 0j) / F(1, 10))
 
         self.assertTypedEquals(0, F(1, 10) // 1)
-        self.assertTypedEquals(0, F(1, 10) // 1.0)
+        if sys.version_info[0] >= 3:
+            self.assertTypedEquals(0, F(1, 10) // 1.0)
+        else:
+            self.assertTypedEquals(0.0, F(1, 10) // 1.0)
         self.assertTypedEquals(10, 1 // F(1, 10))
         self.assertTypedEquals(10**23, 10**22 // F(1, 10))
-        self.assertTypedEquals(10, 1.0 // F(1, 10))
+        if sys.version_info[0] >= 3:
+            self.assertTypedEquals(10, 1.0 // F(1, 10))
+        else:
+            self.assertTypedEquals(10.0, 1.0 // F(1, 10))
 
         self.assertTypedEquals(F(1, 10), F(1, 10) % 1)
         self.assertTypedEquals(0.1, F(1, 10) % 1.0)
@@ -422,9 +431,13 @@ class FractionTest(unittest.TestCase):
         self.assertTypedEquals(0.1, F(1, 10) ** 1.0)
         self.assertTypedEquals(0.1 + 0j, F(1, 10) ** (1.0 + 0j))
         self.assertTypedEquals(4 , 2 ** F(2, 1))
-        z = pow(-1, F(1, 2))
-        self.assertAlmostEqual(0, z.real)
-        self.assertEqual(1, z.imag)
+        try:
+            z = pow(-1, F(1, 2))
+        except ValueError:
+            self.assertEqual(2, sys.version_info[0])
+        else:
+            self.assertAlmostEqual(0, z.real)
+            self.assertEqual(1, z.imag)
         self.assertTypedEquals(F(1, 4) , 2 ** F(-2, 1))
         self.assertTypedEquals(2.0 , 4 ** F(1, 2))
         self.assertTypedEquals(0.25, 2.0 ** F(-2, 1))
